import { DynamicReference } from './DynamicReference';
import type { ErrorReporter } from './ErrorReporter';
export type ToString = {
    toString(): string;
};
interface CubeDefinition {
    name: string;
    extends?: (...args: Array<unknown>) => {
        __cubeName: string;
    };
    sql?: string | (() => string);
    sql_table?: string | (() => string);
    sqlTable?: string | (() => string);
    measures?: Record<string, any>;
    dimensions?: Record<string, any>;
    segments?: Record<string, any>;
    hierarchies?: Record<string, any>;
    preAggregations?: Record<string, any>;
    pre_aggregations?: Record<string, any>;
    joins?: Record<string, any>;
    accessPolicy?: any[];
    includes?: any;
    excludes?: any;
    cubes?: any;
    isView?: boolean;
    isSplitView?: boolean;
    includedMembers?: any[];
}
interface SplitViews {
    [key: string]: any;
}
export declare const CONTEXT_SYMBOLS: {
    SECURITY_CONTEXT: string;
    security_context: string;
    securityContext: string;
    FILTER_PARAMS: string;
    FILTER_GROUP: string;
    SQL_UTILS: string;
};
export declare const CURRENT_CUBE_CONSTANTS: string[];
export declare class CubeSymbols {
    symbols: Record<string | symbol, any>;
    private builtCubes;
    private cubeDefinitions;
    private funcArgumentsValues;
    cubeList: any[];
    private evaluateViews;
    private resolveSymbolsCallContext;
    constructor(evaluateViews?: boolean);
    compile(cubes: CubeDefinition[], errorReporter: ErrorReporter): void;
    getCubeDefinition(cubeName: string): any;
    createCube(cubeDefinition: CubeDefinition): {
        allDefinitions(type: string): any;
        preAggregations: any;
        joins: any;
        measures: any;
        dimensions: any;
        segments: any;
        hierarchies: any;
        accessPolicy: any;
    } & CubeDefinition;
    protected transform(cubeName: string, errorReporter: ErrorReporter, splitViews: SplitViews): any;
    private camelCaseTypes;
    protected transformPreAggregations(preAggregations: Object): void;
    protected transformPreAggregationIndexes(indexes: Object): void;
    protected prepareIncludes(cube: CubeDefinition, errorReporter: ErrorReporter, splitViews: SplitViews): void;
    protected applyIncludeMembers(includeMembers: any[], cube: CubeDefinition, type: string, errorReporter: ErrorReporter): void;
    protected membersFromCubes(parentCube: CubeDefinition, cubes: any[], type: string, errorReporter: ErrorReporter, splitViews: SplitViews, memberSets: any): any[];
    protected diffByMember(includes: any[], excludes: any[]): any[];
    protected getResolvedMember(type: string, cubeName: string, memberName: string): any;
    protected generateIncludeMembers(members: any[], cubeName: string, type: string): any[][];
    /**
     * This method is mainly used for evaluating RLS conditions and filters.
     * It allows referencing security_context (lowecase) in dynamic conditions or filter values.
     *
     * It currently does not support async calls because inner resolveSymbol and
     * resolveSymbolsCall are sync. Async support may be added later with deeper
     * refactoring.
     */
    protected evaluateContextFunction(cube: any, contextFn: any, context?: any): unknown;
    protected evaluateReferences<T extends ToString | Array<ToString>>(cube: string | null, referencesFn: (...args: Array<unknown>) => T, options?: {
        collectJoinHints?: boolean;
        originalSorting?: boolean;
    }): T extends Array<ToString> ? Array<string> : T extends ToString ? string : string | Array<string>;
    pathFromArray(array: any): any;
    protected resolveSymbolsCall<T>(func: (...args: Array<unknown>) => T | DynamicReference<T>, nameResolver: (id: string) => unknown, context?: unknown): T;
    protected withSymbolsCallContext(func: any, context: any): any;
    protected funcArguments(func: any): string[];
    protected joinHints(): any;
    protected resolveSymbolsCallDeps(cubeName: any, sql: any): any[];
    protected depsContextSymbols(): any;
    protected filtersProxyDep(): {};
    protected filterGroupFunctionDep(): (...filterParamArgs: any[]) => string;
    resolveSymbol(cubeName: any, name: any): any;
    protected cubeReferenceProxy(cubeName: any, joinHints?: any[], refProperty?: any): any;
    /**
     * Tries to resolve Granularity object.
     * For predefined granularity it constructs it on the fly.
     * @param {string|string[]} path
     * @param [refCube] Optional cube object to operate on
     */
    resolveGranularity(path: string | string[], refCube?: any): any;
    protected cubeDependenciesProxy(parentIndex: any, cubeName: any): any;
    protected timeDimDependenciesProxy(parentIndex: any): {};
    isCurrentCube(name: any): boolean;
}
export {};
//# sourceMappingURL=CubeSymbols.d.ts.map