/// <reference types="node" />
import { SchemaFileRepository } from '@cubejs-backend/shared';
import { NativeInstance } from '@cubejs-backend/native';
import { LRUCache } from 'lru-cache';
import vm from 'vm';
import { DataSchemaCompiler } from './DataSchemaCompiler';
import { CubeEvaluator } from './CubeEvaluator';
import { ContextEvaluator } from './ContextEvaluator';
import { JoinGraph } from './JoinGraph';
import { CubeToMetaTransformer } from './CubeToMetaTransformer';
import { CompilerCache } from './CompilerCache';
export type PrepareCompilerOptions = {
    nativeInstance?: NativeInstance;
    allowNodeRequire?: boolean;
    allowJsDuplicatePropsInSchema?: boolean;
    maxQueryCacheSize?: number;
    maxQueryCacheAge?: number;
    compileContext?: any;
    standalone?: boolean;
    headCommitId?: string;
    adapter?: string;
    compiledScriptCache?: LRUCache<string, vm.Script>;
};
export declare const prepareCompiler: (repo: SchemaFileRepository, options?: PrepareCompilerOptions) => {
    compiler: DataSchemaCompiler;
    metaTransformer: CubeToMetaTransformer;
    cubeEvaluator: CubeEvaluator;
    contextEvaluator: ContextEvaluator;
    joinGraph: JoinGraph;
    compilerCache: CompilerCache;
    headCommitId: string | undefined;
    compilerId: string;
};
export declare const compile: (repo: SchemaFileRepository, options?: PrepareCompilerOptions) => Promise<{
    compiler: DataSchemaCompiler;
    metaTransformer: CubeToMetaTransformer;
    cubeEvaluator: CubeEvaluator;
    contextEvaluator: ContextEvaluator;
    joinGraph: JoinGraph;
    compilerCache: CompilerCache;
    headCommitId: string | undefined;
    compilerId: string;
}>;
//# sourceMappingURL=PrepareCompiler.d.ts.map